# Awesome !!
 
Well hello there again.
 

https://github.com/willyguggenheim/kubify/runs/7164357389?check_suite_focus=true
vscode in browser (to enable ipad & low ram endpoints to rapid test as well)
autodocument (readthedocs)
cookiecutter for new services, each language (alternative to kubify's own feature, using common tool)
auto-install both local and cloud on kubify start

20) STORY_IN_PROGRESS: cicd, round 1
21) STORY_IN_PROGRESS: dr: automate This DR Failover Solution https://aws.amazon.com/blogs/containers/operating-a-multi-regional-stateless-application-using-amazon-eks/
22) STORY_IN_PROGRESS: dr: automate KubeDB Multi-Region

https://pypi.org/project/awshelper/ for sso (automated check and challange)